"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.name = void 0;
const log = require("loglevel");
const sanitizeFilename_1 = require("../../utils/sanitizeFilename");
const inferTitle_1 = require("../../infer/inferTitle");
const constants_1 = require("../../constants");
async function tryToInferName(targetUrl) {
    try {
        log.debug('Inferring name for', targetUrl);
        const pageTitle = await inferTitle_1.inferTitle(targetUrl);
        return pageTitle || constants_1.DEFAULT_APP_NAME;
    }
    catch (err) {
        log.warn(`Unable to automatically determine app name, falling back to '${constants_1.DEFAULT_APP_NAME}'. Reason: ${err.toString()}`);
        return constants_1.DEFAULT_APP_NAME;
    }
}
async function name(options) {
    if (options.packager.name) {
        log.debug(`Got name ${options.packager.name} from options. No inferring needed`);
        return sanitizeFilename_1.sanitizeFilename(options.packager.platform, options.packager.name);
    }
    const inferredName = await tryToInferName(options.packager.targetUrl);
    return sanitizeFilename_1.sanitizeFilename(options.packager.platform, inferredName);
}
exports.name = name;
//# sourceMappingURL=name.js.map